# Automatically Generated Files

This folder contains files that are automatically generated by the build script
and might be shared between multiple crates in the workspace.

Currently, it is used to build:
- api_map.rs: a public API map used by the docs export pipeline and bindings
- api_objects.txt: a newline-delimited list of public JS-visible objects (wasm-bindgen structs), used to brand JS prototypes during local web builds

Do not edit files in this folder manually.
